@@ -2,7 +2,7 @@
 from pythonapm.logger import agentlogger
 from pythonapm.agentfactory import get_agent
 from pythonapm import constants
-from pythonapm.collector.rescodes import get_rescode_message
+from pythonapm.util import get_rescode_message
 
 def handle_connect_response(res_data={}):
     try:
@@ -20,7 +20,7 @@ def handle_connect_response(res_data={}):
         if res_code is not None and insinfo.get_status() != res_code:
             agentlogger.critical('received response code :'+ str(res_code))
 
-        insinfo.update_instance_info(res_code)
+        insinfo.update_status(res_code)
         return True
     except Exception:
         agentlogger.exception('connect response handler')
